/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const path = require('node:path');
const fs = require('node:fs');
const execa = require('execa');

module.exports.run = function () {
    const projectPath = this.root;

    const xcodebuildClean = configName => {
        return execa(
            'xcodebuild',
            ['-project', 'App.xcodeproj', '-configuration', configName, '-alltargets', 'clean'],
            { cwd: this.root, stdio: 'inherit' }
        );
    };

    return xcodebuildClean('Debug')
        .then(() => xcodebuildClean('Release'))
        .then(() => fs.rmSync(path.join(projectPath, 'build'), { recursive: true, force: true }));
};
